<?php

/**
* Get started notice
*/

add_action( 'wp_ajax_misbah_blog_dismissed_notice_handler', 'misbah_blog_ajax_notice_handler' );

/**
 * AJAX handler to store the state of dismissible notices.
 */
function misbah_blog_ajax_notice_handler() {
    if ( isset( $_POST['type'] ) ) {
        // Pick up the notice "type" - passed via jQuery (the "data-notice" attribute on the notice)
        $type = sanitize_text_field( wp_unslash( $_POST['type'] ) );
        // Store it in the options table
        update_option( 'dismissed-' . $type, TRUE );
    }
}

function misbah_blog_deprecated_hook_admin_notice() {
        // Check if it's been dismissed...
        if ( ! get_option('dismissed-get_started', FALSE ) ) {
            // Added the class "notice-get-started-class" so jQuery pick it up and pass via AJAX,
            // and added "data-notice" attribute in order to track multiple / different notices
            // multiple dismissible notice states ?>

            <?php
            $current_screen = get_current_screen();
				if ($current_screen->id !== 'appearance_page_misbah-blog-guide-page') {
             $misbah_blog_comments_theme = wp_get_theme(); ?>
            <div class="misbah-blog-notice-wrapper updated notice notice-get-started-class is-dismissible" data-notice="get_started">
			<div class="misbah-blog-notice">
				<div class="misbah-blog-notice-img">
					<img src="<?php echo esc_url(get_template_directory_uri() . '/assets/images/admin-logo.png'); ?>" alt="<?php esc_attr_e('logo', 'misbah-blog'); ?>">
				</div>
				<div class="misbah-blog-notice-content">
					<div class="misbah-blog-notice-heading"><?php esc_html_e('Thanks for installing ','misbah-blog'); ?><?php echo esc_html( $misbah_blog_comments_theme ); ?></div>
					<p><?php printf(__('In order to fully benefit from everything our theme has to offer, please make sure you visit our <a href="%s">For Premium Options</a>.', 'misbah-blog'), esc_url(admin_url('themes.php?page=misbah-blog-guide-page'))); ?></p>
					<?php if (is_child_theme()) { ?>
						<?php $child_theme = wp_get_theme(); ?>
						<?php printf(esc_html__('You\'re using %1$s theme, It\'s a child theme of %2$s.', 'misbah-blog'), '<strong>' . $child_theme->Name . '</strong>', '<strong>' . esc_html__('misbah_blog', 'misbah-blog') . '</strong>'); 
						?>
					<?php } ?>
				</div>
			</div>
		</div>
        <?php }
	}
}

add_action( 'admin_notices', 'misbah_blog_deprecated_hook_admin_notice' );

add_action( 'admin_menu', 'misbah_blog_getting_started' );
function misbah_blog_getting_started() {    	    	
	add_theme_page( esc_html__('Get Started', 'misbah-blog'), esc_html__('Get Started', 'misbah-blog'), 'edit_theme_options', 'misbah-blog-guide-page', 'misbah_blog_test_guide');   
}

function misbah_blog_admin_enqueue_scripts() {
	wp_enqueue_style( 'misbah-blog-admin-style', esc_url( get_template_directory_uri() ).'/css/main.css' );
	wp_enqueue_script( 'misbah-blog-admin-script', get_template_directory_uri() . '/js/misbah-blog-admin-script.js', array( 'jquery' ), '', true );
    wp_localize_script( 'misbah-blog-admin-script', 'misbah_blog_ajax_object',
        array( 'ajax_url' => admin_url( 'admin-ajax.php' ) )
    );
}
add_action( 'admin_enqueue_scripts', 'misbah_blog_admin_enqueue_scripts' );

if ( ! defined( 'MISBAH_BLOG_DOCS_FREE' ) ) {
define('MISBAH_BLOG_DOCS_FREE',__('https://www.misbahwp.com/docs/misbah-blog-docs','misbah-blog'));
}
if ( ! defined( 'MISBAH_BLOG_DOCS_PRO' ) ) {
define('MISBAH_BLOG_DOCS_PRO',__('https://www.misbahwp.com/docs/misbah-blog-pro-doc','misbah-blog'));
}
if ( ! defined( 'MISBAH_BLOG_BUY_NOW' ) ) {
define('MISBAH_BLOG_BUY_NOW',__('https://www.misbahwp.com/themes/blog-wordpress-theme/','misbah-blog'));
}
if ( ! defined( 'MISBAH_BLOG_SUPPORT_FREE' ) ) {
define('MISBAH_BLOG_SUPPORT_FREE',__('https://wordpress.org/support/theme/misbah-blog','misbah-blog'));
}
if ( ! defined( 'MISBAH_BLOG_REVIEW_FREE' ) ) {
define('MISBAH_BLOG_REVIEW_FREE',__('https://wordpress.org/support/theme/misbah-blog/reviews/#new-post','misbah-blog'));
}
if ( ! defined( 'MISBAH_BLOG_DEMO_PRO' ) ) {
define('MISBAH_BLOG_DEMO_PRO',__('https://www.misbahwp.com/demo/misbah-blog','misbah-blog'));
}
if( ! defined( 'MISBAH_BLOG_THEME_BUNDLE' ) ) {
define('MISBAH_BLOG_THEME_BUNDLE',__('https://www.misbahwp.com/themes/wordpress-bundle/','misbah-blog'));
}

function misbah_blog_test_guide() { ?>
	<?php $theme = wp_get_theme(); ?>
	
	<div class="wrap" id="main-page">
		<div id="lefty">
			<div id="admin_links">
				<a href="<?php echo esc_url( MISBAH_BLOG_DOCS_FREE ); ?>" target="_blank" class="blue-button-1"><?php esc_html_e( 'Documentation', 'misbah-blog' ) ?></a>			
				<a href="<?php echo esc_url( admin_url('customize.php') ); ?>" id="customizer" target="_blank"><?php esc_html_e( 'Customize', 'misbah-blog' ); ?> </a>
				<a class="blue-button-1" href="<?php echo esc_url( MISBAH_BLOG_SUPPORT_FREE ); ?>" target="_blank" class="btn3"><?php esc_html_e( 'Support', 'misbah-blog' ) ?></a>
				<a class="blue-button-2" href="<?php echo esc_url( MISBAH_BLOG_REVIEW_FREE ); ?>" target="_blank" class="btn4"><?php esc_html_e( 'Review', 'misbah-blog' ) ?></a>
			</div>
			<div id="description">
				<h3><?php esc_html_e('Welcome! Thank you for choosing ','misbah-blog'); ?><?php echo esc_html( $theme ); ?>  <span><?php esc_html_e('Version: ', 'misbah-blog'); ?><?php echo esc_html($theme['Version']);?></span></h3>
				<img class="img_responsive" style="width:100%;" src="<?php echo esc_url( get_template_directory_uri() ); ?>/screenshot.png">
				<div id="description-insidee">
					<?php
						$theme = wp_get_theme();
						echo wp_kses_post( apply_filters( 'misbah_theme_description', esc_html( $theme->get( 'Description' ) ) ) );
					?>
				</div>
			</div>
		</div>

		<div id="righty">
			<div class="postboxx donate">
				<h3 class="hndle"><?php esc_html_e( 'Upgrade to Premium', 'misbah-blog' ); ?></h3>
				<div class="insidee">
					<p><?php esc_html_e('Discover upgraded pro features with premium version click to upgrade.','misbah-blog'); ?></p>
					<div id="admin_pro_links">
						<a class="blue-button-2" href="<?php echo esc_url( MISBAH_BLOG_BUY_NOW ); ?>" target="_blank"><?php esc_html_e( 'Go Pro', 'misbah-blog' ); ?></a>
						<a class="blue-button-1" href="<?php echo esc_url( MISBAH_BLOG_DEMO_PRO ); ?>" target="_blank"><?php esc_html_e( 'Live Demo', 'misbah-blog' ) ?></a>
						<a class="blue-button-2" href="<?php echo esc_url( MISBAH_BLOG_DOCS_PRO ); ?>" target="_blank"><?php esc_html_e( 'Pro Docs', 'misbah-blog' ) ?></a>
					</div>
				</div>
				<h3 class="hndle bundle"><?php esc_html_e( 'Go For Theme Bundle', 'misbah-blog' ); ?></h3>
				<div class="insidee theme-bundle">
					<p class="offer"><?php esc_html_e('Get 80+ Perfect WordPress Theme In A Single Package at just $79."','misbah-blog'); ?></p>
					<p class="coupon"><?php esc_html_e('Exclusive Offer !! Get Our Theme Pack of 60+ WordPress Themes At 10% Off','misbah-blog'); ?><span class="coupon-code"><?php esc_html_e('"Themespack10"','misbah-blog'); ?></span></p>
					<div id="admin_pro_linkss">
						<a class="blue-button-1" href="<?php echo esc_url( MISBAH_BLOG_THEME_BUNDLE ); ?>" target="_blank"><?php esc_html_e( 'Theme Bundle', 'misbah-blog' ) ?></a>
					</div>
				</div>
				<div class="d-table">
			    <ul class="d-column">
			      <li class="feature"><?php esc_html_e('Features','misbah-blog'); ?></li>
			      <li class="free"><?php esc_html_e('Pro','misbah-blog'); ?></li>
			      <li class="plus"><?php esc_html_e('Free','misbah-blog'); ?></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('24hrs Priority Support','misbah-blog'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-yes"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('Kirki Framework','misbah-blog'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-yes"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('One Click Demo Import','misbah-blog'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-no"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('Section Reordering','misbah-blog'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-no"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('Enable / Disable Option','misbah-blog'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-yes"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('Multiple Sections','misbah-blog'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-no"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('Advance Color Pallete','misbah-blog'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-no"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('Advance Widgets','misbah-blog'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-yes"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('Page Templates','misbah-blog'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-no"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('Advance Typography','misbah-blog'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-no"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('Section Background Image / Color ','misbah-blog'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-no"></span></li>
			    </ul>		    
	  		</div>
			</div>
		</div>
	</div>

<?php } ?>
