<?php

/*-----------------------------------------------------------------------------------*/
/* Enqueue script and styles */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('misbah_blog_enqueue_scripts')) {

	require_once get_theme_file_path( 'core/includes/wptt-webfont-loader.php' );

	function misbah_blog_enqueue_scripts() {

		$googleFontsArgs = array(
			'family' =>	str_replace('|', '%7C','Poppins:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i'),
			'subset' =>	'latin,latin-ext'
		);

		wp_enqueue_style('google-fonts', add_query_arg ( $googleFontsArgs, "https://fonts.googleapis.com/css" ), array(), '1.0.0' );

		wp_enqueue_style(
			'bootstrap-css',
			get_template_directory_uri() . '/css/bootstrap.css',
			array(),'4.5.0'
		);

		wp_enqueue_style(
			'fontawesome-css',
			get_template_directory_uri() . '/css/fontawesome-all.css',
			array(),'4.5.0'
		);

		wp_enqueue_style(
			'owl.carousel-css',
			get_template_directory_uri() . '/css/owl.carousel.css',
			array(),'2.3.4'
		);

		wp_enqueue_style('misbah-blog-style', get_stylesheet_uri(), array() );

		wp_style_add_data('misbah-blog-style', 'rtl', 'replace');

		wp_enqueue_style(
			'misbah-blog-media-css',
			get_template_directory_uri() . '/css/media.css',
			array(),'2.3.4'
		);

		wp_enqueue_style(
			'misbah-blog-woocommerce-css',
			get_template_directory_uri() . '/css/woocommerce.css',
			array(),'2.3.4'
		);

		wp_enqueue_style(
			'dashicons',
			get_template_directory_uri(),
			array(),'2.3.4'
		);

		wp_enqueue_script(
			'misbah-blog-navigation',
			get_template_directory_uri() . '/js/navigation.js',
			FALSE,
			'1.0',
			TRUE
		);

		wp_enqueue_script(
			'owl.carousel-js',
			get_template_directory_uri() . '/js/owl.carousel.js',
			array('jquery'),
			'2.3.4',
			TRUE
		);

		wp_enqueue_script(
			'misbah-blog-script',
			get_template_directory_uri() . '/js/script.js',
			array('jquery'),
			'1.0',
			TRUE
		);

		if ( is_singular() ) wp_enqueue_script( 'comment-reply' );

		$misbah_blog_css = '';

		if ( get_header_image() ) :

			$misbah_blog_css .=  '
				header.header {
					background-image: url('.esc_url(get_header_image()).');
					-webkit-background-size: cover !important;
					-moz-background-size: cover !important;
					-o-background-size: cover !important;
					background-size: cover !important;
				}';

		endif;

		wp_add_inline_style( 'misbah-blog-style', $misbah_blog_css );

		// Theme Customize CSS.
		require get_template_directory(). '/core/includes/inline.php';
		wp_add_inline_style( 'misbah-blog-style',$misbah_blog_custom_css );

	}

	add_action( 'wp_enqueue_scripts', 'misbah_blog_enqueue_scripts' );

}

/*-----------------------------------------------------------------------------------*/
/* Setup theme */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('misbah_blog_after_setup_theme')) {

	function misbah_blog_after_setup_theme() {

		if ( ! isset( $misbah_blog_content_width ) ) $misbah_blog_content_width = 900;

		register_nav_menus( array(
			'main-menu' => esc_html__( 'Main menu', 'misbah-blog' ),
		));

		add_theme_support( 'responsive-embeds' );
		add_theme_support( 'align-wide' );
		add_theme_support('title-tag');
		add_theme_support('automatic-feed-links');
		add_theme_support('post-thumbnails');
		add_theme_support( 'wp-block-styles' );
		add_theme_support( 'woocommerce' );
		add_theme_support( 'custom-background', array(
		  'default-color' => 'f3f3f3'
		));

		add_theme_support( 'custom-logo', array(
			'height'      => 70,
			'width'       => 70,
		) );

		add_theme_support( 'custom-header', array(
			'width' => 1920,
			'height' => 100
		));

		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		add_theme_support( 'post-formats', array('image','video','gallery','audio',) );

		add_editor_style( array( '/css/editor-style.css' ) );
	}

	add_action( 'after_setup_theme', 'misbah_blog_after_setup_theme', 999 );

}
require get_template_directory() .'/core/includes/main.php';
require get_template_directory() .'/core/includes/tgm.php';
require get_template_directory() . '/core/includes/customizer.php';
load_template( trailingslashit( get_template_directory() ) . '/core/includes/class-upgrade-pro.php' );

/**------------------------------------------------------------------------------------------
 * Enqueue theme logo style.
 */
function misbah_blog_logo_resizer() {

    $misbah_blog_theme_logo_size_css = '';
    $misbah_blog_logo_resizer = get_theme_mod('misbah_blog_logo_resizer');

	$misbah_blog_theme_logo_size_css = '
		.custom-logo{
			height: '.esc_attr($misbah_blog_logo_resizer).'px !important;
			width: '.esc_attr($misbah_blog_logo_resizer).'px !important;
		}
	';
    wp_add_inline_style( 'misbah-blog-style',$misbah_blog_theme_logo_size_css );

}
add_action( 'wp_enqueue_scripts', 'misbah_blog_logo_resizer' );

/*-----------------------------------------------------------------------------------*/
/* Enqueue Global color style */
/*-----------------------------------------------------------------------------------*/
function misbah_blog_global_color() {

    $misbah_blog_theme_color_css = '';
    $misbah_blog_global_color = get_theme_mod('misbah_blog_global_color');
    $misbah_blog_global_color_2 = get_theme_mod('misbah_blog_global_color_2');

	$misbah_blog_theme_color_css = '
		.header-search .open-search-form i,.post-cat span,.comment-respond input#submit,.comment-reply a,.sidebar-area .tagcloud a:hover,.searchform input[type=submit],.menu-toggle,.dropdown-toggle,nav.woocommerce-MyAccount-navigation ul li,.woocommerce .woocommerce-info .button, .woocommerce .woocommerce-message .button,.woocommerce-page .woocommerce-info .button, .woocommerce-page .woocommerce-message .button,.woocommerce button.button,.woocommerce a.button,.woocommerce a.button.alt,.woocommerce a.button,.woocommerce button.button.alt,.woocommerce button.button,.scroll-up a,.woocommerce #respond input#submit.alt, .woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt, .woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button, .woocommerce a.added_to_cart,.sidebar-area .tagcloud a,.sidebar-area h4.title, p.wp-block-tag-cloud a, .wp-block-button__link,.sidebar-area h4.title, .sidebar-area h1.wp-block-heading,.sidebar-area h2.wp-block-heading,.sidebar-area h3.wp-block-heading,.sidebar-area h4.wp-block-heading,.sidebar-area h5.wp-block-heading,.sidebar-area h6.wp-block-heading,.sidebar-area .wp-block-search__label,.sidebar-area .wp-block-search__button {
			background: '.esc_attr($misbah_blog_global_color).';
		}
		a:hover,a:focus,.social-links a:hover,#main-menu a:hover,#main-menu ul li a:hover,#main-menu li:hover > a,#main-menu a:focus,#main-menu ul li a:focus,#main-menu li.focus > a,#main-menu li:focus > a,#main-menu ul li.current-menu-item > a,#main-menu ul li.current_page_item > a,#main-menu ul li.current-menu-parent > a,#main-menu ul li.current_page_ancestor > a,#main-menu ul li.current-menu-ancestor > a,.featured_post h3,.post-meta i {
			color: '.esc_attr($misbah_blog_global_color).';
		}
		.featured_post h3, sh2{
			border-color: '.esc_attr($misbah_blog_global_color).';
		}
		.header,footer,nav.woocommerce-MyAccount-navigation ul li:hover,.woocommerce #respond input#submit.alt:hover, .woocommerce a.button.alt:hover, .woocommerce button.button.alt:hover, .woocommerce input.button.alt:hover,.woocommerce #respond input#submit:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button:hover,.woocommerce a.added_to_cart:hover,.woocommerce ul.products li.product .onsale,.woocommerce span.onsale,.scroll-up a:hover,.comment-respond input#submit:hover,.comment-reply a:hover{
			background: '.esc_attr($misbah_blog_global_color_2).';
		}
		body,a,.woocommerce ul.products li.product .price,.woocommerce div.product p.price, .woocommerce div.product span.price,.sidebar-area .tagcloud a,pre,#main-menu ul li a {
			color: '.esc_attr($misbah_blog_global_color_2).';
		}
		.sidebar-area select,.sidebar-area textarea, #comments textarea,.sidebar-area input[type="text"], #comments input[type="text"],.sidebar-area input[type="password"],.sidebar-area input[type="datetime"],.sidebar-area input[type="datetime-local"],.sidebar-area input[type="date"],.sidebar-area input[type="month"],.sidebar-area input[type="time"],.sidebar-area input[type="week"],.sidebar-area input[type="number"],.sidebar-area input[type="email"],.sidebar-area input[type="url"],.sidebar-area input[type="search"],.sidebar-area input[type="tel"],.sidebar-area input[type="color"],.sidebar-area .uneditable-input, .sidebar-area h4.title, .sidebar-area h1.wp-block-heading,.sidebar-area h2.wp-block-heading,.sidebar-area h3.wp-block-heading,.sidebar-area h4.wp-block-heading,.sidebar-area h5.wp-block-heading,.sidebar-area h6.wp-block-heading,.sidebar-area .wp-block-search__label,.sh2{
			border-color: '.esc_attr($misbah_blog_global_color_2).';
		}
	';
    wp_add_inline_style( 'misbah-blog-style',$misbah_blog_theme_color_css );
    wp_add_inline_style( 'misbah-blog-woocommerce-css',$misbah_blog_theme_color_css );

}
add_action( 'wp_enqueue_scripts', 'misbah_blog_global_color' );

/*-----------------------------------------------------------------------------------*/
/* Get post comments */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('misbah_blog_comment')) :
    /**
     * Template for comments and pingbacks.
     *
     * Used as a callback by wp_list_comments() for displaying the comments.
     */
    function misbah_blog_comment($comment, $args, $depth){

        if ('pingback' == $comment->comment_type || 'trackback' == $comment->comment_type) : ?>

            <li id="comment-<?php comment_ID(); ?>" <?php comment_class('media'); ?>>
            <div class="comment-body">
                <?php esc_html_e('Pingback:', 'misbah-blog');
                comment_author_link(); ?><?php edit_comment_link(__('Edit', 'misbah-blog'), '<span class="edit-link">', '</span>'); ?>
            </div>

        <?php else : ?>

        <li id="comment-<?php comment_ID(); ?>" <?php comment_class(empty($args['has_children']) ? '' : 'parent'); ?>>
            <article id="div-comment-<?php comment_ID(); ?>" class="comment-body media mb-4">
                <a class="pull-left" href="#">
                    <?php if (0 != $args['avatar_size']) echo get_avatar($comment, $args['avatar_size']); ?>
                </a>
                <div class="media-body">
                    <div class="media-body-wrap card">
                        <div class="card-header">
                            <h5 class="mt-0"><?php /* translators: %s: author */ printf('<cite class="fn">%s</cite>', get_comment_author_link() ); ?></h5>
                            <div class="comment-meta">
                                <a href="<?php echo esc_url(get_comment_link($comment->comment_ID)); ?>">
                                    <time datetime="<?php comment_time('c'); ?>">
                                        <?php /* translators: %s: Date */ printf( esc_attr('%1$s at %2$s', '1: date, 2: time', 'misbah-blog'), esc_attr( get_comment_date() ), esc_attr( get_comment_time() ) ); ?>
                                    </time>
                                </a>
                                <?php edit_comment_link( __( 'Edit', 'misbah-blog' ), '<span class="edit-link">', '</span>' ); ?>
                            </div>
                        </div>

                        <?php if ('0' == $comment->comment_approved) : ?>
                            <p class="comment-awaiting-moderation"><?php esc_html_e('Your comment is awaiting moderation.', 'misbah-blog'); ?></p>
                        <?php endif; ?>

                        <div class="comment-content card-block">
                            <?php comment_text(); ?>
                        </div>

                        <?php comment_reply_link(
                            array_merge(
                                $args, array(
                                    'add_below' => 'div-comment',
                                    'depth' => $depth,
                                    'max_depth' => $args['max_depth'],
                                    'before' => '<footer class="reply comment-reply card-footer">',
                                    'after' => '</footer><!-- .reply -->'
                                )
                            )
                        ); ?>
                    </div>
                </div>
            </article>

            <?php
        endif;
    }
endif; // ends check for misbah_blog_comment()

if (!function_exists('misbah_blog_widgets_init')) {

	function misbah_blog_widgets_init() {

		register_sidebar(array(

			'name' => esc_html__('Front Page Sidebar','misbah-blog'),
			'id'   => 'misbah-blog-front-page-sidebar',
			'description'   => esc_html__('This sidebar will be shown on home page next to the content.', 'misbah-blog'),
			'before_widget' => '<div id="%1$s" class="sidebar-widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="title">',
			'after_title'   => '</h4>'

		));

		register_sidebar(array(

			'name' => esc_html__('Sidebar','misbah-blog'),
			'id'   => 'misbah-blog-sidebar',
			'description'   => esc_html__('This sidebar will be shown next to the content.', 'misbah-blog'),
			'before_widget' => '<div id="%1$s" class="sidebar-widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="title">',
			'after_title'   => '</h4>'

		));

		register_sidebar(array(

			'name' => esc_html__('Footer sidebar','misbah-blog'),
			'id'   => 'misbah-blog-footer-sidebar',
			'description'   => esc_html__('This sidebar will be shown next at the bottom of your content.', 'misbah-blog'),
			'before_widget' => '<div id="%1$s" class="col-lg-3 col-md-3 %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="title">',
			'after_title'   => '</h4>'

		));

	}

	add_action( 'widgets_init', 'misbah_blog_widgets_init' );

}

function misbah_blog_get_categories_select() {
	$misbah_blog_teh_cats = get_categories();
	$results;
	$misbah_blog_count = count($misbah_blog_teh_cats);
	for ($i=0; $i < $misbah_blog_count; $i++) {
	if (isset($misbah_blog_teh_cats[$i]))
  		$results[$misbah_blog_teh_cats[$i]->slug] = $misbah_blog_teh_cats[$i]->name;
	else
  		$misbah_blog_count++;
	}
	return $results;
}

function misbah_blog_remove_sections( $wp_customize ) {
	$wp_customize->remove_control('display_header_text');
	$wp_customize->remove_setting('display_header_text');
}
add_action( 'customize_register', 'misbah_blog_remove_sections');


add_action('after_switch_theme', 'misbah_blog_setup_options');
function misbah_blog_setup_options () {
    update_option('dismissed-get_started', FALSE );
}

// Change number or products per row to 3
add_filter('loop_shop_columns', 'misbah_blog_loop_columns');
if (!function_exists('misbah_blog_loop_columns')) {
	function misbah_blog_loop_columns() {
		$misbah_blog_columns = get_theme_mod( 'misbah_blog_per_columns', 3 );
		return $misbah_blog_columns;
	}
}

//Change number of products that are displayed per page (shop page)
add_filter( 'loop_shop_per_page', 'misbah_blog_per_page', 20 );
function misbah_blog_per_page( $misbah_blog_cols ) {
  	$misbah_blog_cols = get_theme_mod( 'misbah_blog_product_per_page', 9 );
	return $misbah_blog_cols;
}

// Add filter to modify the number of related products
add_filter( 'woocommerce_output_related_products_args', 'misbah_blog_products_args' );
function misbah_blog_products_args( $args ) {
    $args['posts_per_page'] = get_theme_mod( 'custom_related_products_number', 6 );
    $args['columns'] = get_theme_mod( 'custom_related_products_number_per_row', 3 );
    return $args;
}

?>
